@@ -76,6 +76,8 @@ def create_ducktape_parser():
                         "nodes for services. Can be used when running specific tests on a running platform")
     parser.add_argument("--sample", action="store", type=int,
                         help="The size of a random test sample to run")
+    parser.add_argument("--fail-bad-cluster-utilization", action="store_true",
+                        help="Fail a test if the cluster node utilization does not match the cluster node usage.")
     return parser
 
 
