@@ -23,7 +23,7 @@ import pkg_resources
 
 from ducktape.utils.terminal_size import get_terminal_size
 from ducktape.utils.util import ducktape_version
-from ducktape.tests.status import PASS, FAIL, IGNORE, FLAKY
+from ducktape.tests.status import PASS, FAIL, IGNORE
 from ducktape.json_serializable import DucktapeJSONEncoder
 
 
@@ -109,7 +109,6 @@ class SimpleSummaryReporter(SummaryReporter):
             "run time:         %s" % format_time(self.results.run_time_seconds),
             "tests run:        %d" % len(self.results),
             "passed:           %d" % self.results.num_passed,
-            "flaky:            %d" % self.results.num_flaky,
             "failed:           %d" % self.results.num_failed,
             "ignored:          %d" % self.results.num_ignored,
             "=" * self.width
@@ -178,7 +177,7 @@ class JUnitReporter(object):
             elif result.test_status == IGNORE:
                 testsuite['skipped'] += 1
 
-        total = self.results.num_failed + self.results.num_ignored + self.results.num_passed + self.results.num_flaky
+        total = self.results.num_failed + self.results.num_ignored + self.results.num_passed
         # Now start building XML document
         root = ET.Element('testsuites', attrib=dict(
             name="ducktape", time=str(self.results.run_time_seconds),
@@ -240,7 +239,6 @@ class HTMLSummaryReporter(SummaryReporter):
             "run_time": format_time(result.run_time_seconds),
             "data": "" if result.data is None else json.dumps(result.data, sort_keys=True,
                                                               indent=2, separators=(',', ': ')),
-            "summary": result.summary,
             "test_log": self.test_results_dir(result)
         }
         return result_json
@@ -262,43 +260,35 @@ class HTMLSummaryReporter(SummaryReporter):
 
         num_tests = len(self.results)
         num_passes = 0
-        failed_result_string = []
-        passed_result_string = []
-        ignored_result_string = []
-        flaky_result_string = []
+        failed_result_string = ""
+        passed_result_string = ""
+        ignored_result_string = ""
 
         for result in self.results:
             json_string = json.dumps(self.format_result(result))
             if result.test_status == PASS:
                 num_passes += 1
-                passed_result_string.append(json_string)
-                passed_result_string.append(",")
+                passed_result_string += json_string
+                passed_result_string += ","
             elif result.test_status == FAIL:
-                failed_result_string.append(json_string)
-                failed_result_string.append(",")
-            elif result.test_status == IGNORE:
-                ignored_result_string.append(json_string)
-                ignored_result_string.append(",")
-            elif result.test_status == FLAKY:
-                flaky_result_string.append(json_string)
-                flaky_result_string.append(",")
+                failed_result_string += json_string
+                failed_result_string += ","
             else:
-                raise Exception("Unknown test status in report: {}".format(result.test_status.to_json()))
+                ignored_result_string += json_string
+                ignored_result_string += ","
 
         args = {
             'ducktape_version': ducktape_version(),
             'num_tests': num_tests,
             'num_passes': self.results.num_passed,
-            'num_flaky': self.results.num_flaky,
             'num_failures': self.results.num_failed,
             'num_ignored': self.results.num_ignored,
             'run_time': format_time(self.results.run_time_seconds),
             'session': self.results.session_context.session_id,
-            'passed_tests': "".join(passed_result_string),
-            'flaky_tests': "".join(flaky_result_string),
-            'failed_tests': "".join(failed_result_string),
-            'ignored_tests': "".join(ignored_result_string),
-            'test_status_names': ",".join(["\'%s\'" % str(status) for status in [PASS, FAIL, IGNORE, FLAKY]])
+            'passed_tests': passed_result_string,
+            'failed_tests': failed_result_string,
+            'ignored_tests': ignored_result_string,
+            'test_status_names': ",".join(["\'%s\'" % str(status) for status in [PASS, FAIL, IGNORE]])
         }
 
         html = template % args
