@@ -21,6 +21,8 @@ import os.path
 import pytest
 import re
 import requests
+import tempfile
+import yaml
 
 from mock import Mock
 from requests_testadapter import Resp
@@ -111,6 +113,26 @@ class CheckTestLoader(object):
             loader.load([suite_file_path])
 
     @pytest.mark.parametrize(['expected_count', 'input_symbols', 'excluded_symbols'], [
+        pytest.param(6, [
+            # import a single test suite with an import statement
+            os.path.join(discover_dir(), 'test_suite_with_single_import.yml')
+        ], None, id='load dependency path'),
+        pytest.param(2, [
+            # test that a self import doesn't cause an infinite loop
+            os.path.join(discover_dir(), 'test_suite_with_self_import.yml')
+        ], None, id='self load in import'),
+        pytest.param(5, [
+            # test that a cyclic import doesn't cause an infinite loop
+            os.path.join(discover_dir(), 'test_suite_cyclic_b.yml')
+        ], None, id='self load in import'),
+        pytest.param(5, [
+            # test that a cyclic import starting with second import
+            os.path.join(discover_dir(), 'test_suite_cyclic_a.yml')
+        ], None, id='self load in import'),
+        pytest.param(5, [
+            # test single import statement with parent reference
+            os.path.join(discover_dir(), 'test_suites', 'sub_dir_test_import.yml')
+        ], None, id='self load in import'),
         pytest.param(8, [
             # see test suite files for number of tests in it.
             # decorated test suite includes 2 tests;
@@ -302,6 +324,17 @@ class CheckTestLoader(object):
         assert len(tests) == 1
         assert tests[0].injected_args == {'x': 1, 'y': 'test '}
 
+    def check_test_loader_with_params_special_chars(self):
+        loader = TestLoader(self.SESSION_CONTEXT, logger=Mock())
+        included = [os.path.join(discover_dir(
+        ), r'test_decorated.py::TestParametrizdeSpecial.test_special_characters_params'
+           r'@{"version": "6.1.0", "chars": "!@#$%^&*()_+::.,/? \"{}\\"}')]
+        tests = loader.load(included)
+        # TestMatrix contains a single parametrized method. Since we only provide a single set of params, we should
+        # end up with a single context
+        assert len(tests) == 1
+        assert tests[0].injected_args == {'version': '6.1.0', 'chars': '!@#$%^&*()_+::.,/? \"{}\\'}
+
     def check_test_loader_with_multiple_matrix_params(self):
         loader = TestLoader(self.SESSION_CONTEXT, logger=Mock())
         params = '[{"x": 1,"y": "test "}, {"x": 2,"y": "I\'m"}]'
@@ -344,7 +377,7 @@ class CheckTestLoader(object):
 
         file = os.path.join(discover_dir(), "test_decorated.py")
         tests = loader.load([file])
-        assert len(tests) == 5
+        assert len(tests) == 6
 
         for t in tests:
             assert t.injected_args == injected_args
@@ -390,7 +423,7 @@ class CheckTestLoader(object):
         # test_decorated.py contains 5 test methods total
         # we exclude 1 class with 1 method so should be 4
         # exclusion shouldn't care about injected args
-        assert len(tests) == 4
+        assert len(tests) == 5
 
         for t in tests:
             assert t.injected_args == injected_args
@@ -429,14 +462,14 @@ class CheckTestLoader(object):
 
         file = os.path.join(discover_dir(), "test_decorated.py")
 
-        # The test file contains 17 tests. With 4 subsets, first subset should have an "extra"
+        # The test file contains 18 tests. With 4 subsets, first two subset should have an "extra"
         loader = TestLoader(self.SESSION_CONTEXT, logger=Mock(), subset=0, subsets=4)
         tests = loader.load([file])
         assert len(tests) == 5
 
         loader = TestLoader(self.SESSION_CONTEXT, logger=Mock(), subset=1, subsets=4)
         tests = loader.load([file])
-        assert len(tests) == 4
+        assert len(tests) == 5
 
         loader = TestLoader(self.SESSION_CONTEXT, logger=Mock(), subset=2, subsets=4)
         tests = loader.load([file])
@@ -473,6 +506,48 @@ class CheckTestLoader(object):
         tests = loader.load([file])
         assert len(tests) == 2
 
+    def check_loader_with_non_yml_file(self):
+        """
+        test loading a test file as an import
+        """
+        file = os.path.join(discover_dir(), 'test_suite_import_py.yml')
+        loader = TestLoader(self.SESSION_CONTEXT, logger=Mock())
+        with pytest.raises(LoaderException, match=r'Failed to load test suite from file: \S+test_a\.py'):
+            loader.load([file])
+
+    def check_loader_with_non_suite_yml_file(self):
+        """
+        test importing a suite that is malformed
+        """
+        file1 = os.path.join(discover_dir(), 'test_suite_malformed.yml')
+        file2 = os.path.join(discover_dir(), 'test_suite_import_malformed.yml')
+        loader = TestLoader(self.SESSION_CONTEXT, logger=Mock())
+        with pytest.raises(LoaderException, match='No tests found in  simple_malformed_suite'):
+            loader.load([file1])
+        with pytest.raises(LoaderException, match='No tests found in  simple_malformed_suite'):
+            loader.load([file2])
+
+    def check_test_loader_with_absolute_path(self):
+        """
+        Test loading suites using absolute paths to other imported suites as well as absolute paths
+        to tests in the suite
+        """
+        with tempfile.TemporaryDirectory() as td:
+            temp_suite1 = os.path.join(td, 'temp_suite1.yml')
+            temp_suite2 = os.path.join(td, 'temp_suite2.yml')
+            with open(temp_suite1, 'w') as f:
+                test_yaml1 = yaml.dump({'import': str(os.path.join(td, 'temp_suite2.yml')),
+                                        'suite': [os.path.abspath(os.path.join(discover_dir(), "test_a.py"))]})
+                f.write(test_yaml1)
+
+            with open(temp_suite2, 'w') as f:
+                test_yaml2 = yaml.dump({'suite': [os.path.abspath(os.path.join(discover_dir(), "test_b.py"))]})
+                f.write(test_yaml2)
+
+            loader = TestLoader(self.SESSION_CONTEXT, logger=Mock())
+            tests = loader.load([temp_suite1])
+            assert len(tests) == 4
+
 
 def join_parsed_symbol_components(parsed):
     """
